@@ -19,17 +19,13 @@ Nagios::MKLivestatus::INET - connector with tcp sockets
 
 =head1 CONSTRUCTOR
 
-=over 4
-
-=item new ( [ARGS] )
+=head2 new ( [ARGS] )
 
 Creates an C<Nagios::MKLivestatus::INET> object. C<new> takes at least the server.
 Arguments are the same as in C<Nagios::MKLivestatus>.
 If the constructor is only passed a single argument, it is assumed to
 be a the C<server> specification. Use either socker OR server.
 
-=back
-
 =cut
 
 sub new {
@@ -44,34 +40,42 @@ sub new {
 }
 
 
+########################################
+
+=head1 METHODS
+
+=cut
+
+sub _open {
+    my $self = shift;
+    my $sock = IO::Socket::INET->new(
+                                     PeerAddr => $self->{'server'},
+                                     timeout  => $self->{'timeout'},
+                                     );
+    if(!defined $sock or !$sock->connected()) {
+        my $msg = "failed to connect to $self->{'server'} :$!";
+        if($self->{'errors_are_fatal'}) {
+            croak($msg);
+        }
+        $Nagios::MKLivestatus::ErrorCode    = 500;
+        $Nagios::MKLivestatus::ErrorMessage = $msg;
+        return;
+    }
+    return($sock);
+}
+
 
 ########################################
-sub _send_socket {
-    my $self      = shift;
-    my $statement = shift;
 
-    croak("no statement") if !defined $statement;
-
-    my $sock = IO::Socket::INET->new($self->{'server'});
-    if(!defined $sock or !$sock->connected()) {
-        croak("failed to connect to $self->{'server'}: $!");
-    }
-
-    my $recv;
-    print $sock $statement;
-    $sock->shutdown(1) or croak("shutdown failed: $!");
-    while(<$sock>) { $recv .= $_; }
-    close($sock);
-
-    return if !defined $recv;
-
-    return($recv);
+sub _close {
+    my $self = shift;
+    my $sock = shift;
+    return close($sock);
 }
 
 
 1;
 
-
 =head1 AUTHOR
 
 Sven Nierlein, E<lt>nierlein@cpan.orgE<gt>
