@@ -19,9 +19,7 @@ Nagios::MKLivestatus::UNIX - connector with unix sockets
 
 =head1 CONSTRUCTOR
 
-=over 4
-
-=item new ( [ARGS] )
+=head2 new ( [ARGS] )
 
 Creates an C<Nagios::MKLivestatus::UNIX> object. C<new> takes at least the socketpath.
 Arguments are the same as in C<Nagios::MKLivestatus>.
@@ -29,10 +27,9 @@ Arguments are the same as in C<Nagios::MKLivestatus>.
 If the constructor is only passed a single argument, it is assumed to
 be a the C<socket> specification. Use either socker OR server.
 
-=back
-
 =cut
 
+
 sub new {
     my $class = shift;
     unshift(@_, "socket") if scalar @_ == 1;
@@ -44,36 +41,46 @@ sub new {
     return $self;
 }
 
+
 ########################################
-sub _send_socket {
+
+=head1 METHODS
+
+=cut
+
+sub _open {
     my $self      = shift;
-    my $statement = shift;
-
-    croak("no statement") if !defined $statement;
-
     if(!-S $self->{'socket'}) {
         croak("failed to open socket $self->{'socket'}: $!");
     }
-    my $sock = IO::Socket::UNIX->new($self->{'socket'});
+    my $sock = IO::Socket::UNIX->new(
+                                        Peer     => $self->{'socket'},
+                                        timeout  => $self->{'timeout'},
+                                     );
     if(!defined $sock or !$sock->connected()) {
-        croak("failed to connect to ($self->{'socket'}): $!");
+        my $msg = "failed to connect to $self->{'socket'} :$!";
+        if($self->{'errors_are_fatal'}) {
+            croak($msg);
+        }
+        $Nagios::MKLivestatus::ErrorCode    = 500;
+        $Nagios::MKLivestatus::ErrorMessage = $msg;
+        return;
     }
+    return($sock);
+}
 
-    my $recv;
-    print $sock $statement;
-    $sock->shutdown(1) or croak("shutdown failed: $!");
-    while(<$sock>) { $recv .= $_; }
-    close($sock);
 
-    return if !defined $recv;
+########################################
 
-    return($recv);
+sub _close {
+    my $self = shift;
+    my $sock = shift;
+    return close($sock);
 }
 
 
 1;
 
-
 =head1 AUTHOR
 
 Sven Nierlein, E<lt>nierlein@cpan.orgE<gt>
